<template>
  <div>
    <!-- Table Container Card -->
    <b-card no-body class="mb-0">
      <div class="m-2">
        <!-- Table Top -->
        <b-row>
          <!-- Per Page -->
          <b-col
            cols="12"
            md="6"
            class="d-flex align-items-center justify-content-start mb-1 mb-md-0"
          >
            <label>Show</label>
            <v-select
              v-model="perPage"
              :dir="$store.state.appConfig.isRTL ? 'rtl' : 'ltr'"
              :options="perPageOptions"
              :clearable="false"
              class="per-page-selector d-inline-block mx-50"
            />
            <label>entries</label>
          </b-col>

          <!-- Search -->
          <b-col cols="12" md="6">
            <div class="d-flex align-items-center justify-content-end">
              <!-- 搜尋框 -->
              <!-- <b-form-input
                v-model="searchQuery"
                class="d-inline-block mr-1"
                placeholder="Search..."
              /> -->
              <b-button
                variant="primary"
                :to="{ name: 'promotions-discounts-add' }"
              >
                <span class="text-nowrap">新增</span>
              </b-button>
            </div>
          </b-col>
        </b-row>
      </div>

      <b-table
        ref="promotionTable"
        class="position-relative"
        :items="fetchPromotions"
        responsive
        :fields="tableColumns"
        primary-key="id"
        :sort-by.sync="sortBy"
        show-empty
        empty-text="目前沒有任何滿額贈"
        :sort-desc.sync="isSortDirDesc"
      >
        <!-- Column: id -->
        <template #cell(id)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{
              data.item.id
            }}</span>
          </div>
        </template>

        <!-- Column: name -->
        <template #cell(name)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{
              data.item.name
            }}</span>
          </div>
        </template>

        <!-- Column: discount_amounts -->
        <template #cell(discount_amounts)="data">
          <div class="text-nowrap">
            <div
              v-for="(condition, index) in data.item.conditions"
              :key="condition.id"
            >
              <span class="align-text-top text-capitalize">
                {{ index + 1 }}. 折 {{ condition.discount_amount }} 元
              </span>
            </div>
          </div>
        </template>

        <!-- Column: conditions -->
        <template #cell(conditions)="data">
          <div class="text-nowrap">
            <div
              v-for="(condition, index) in data.item.conditions"
              :key="condition.id"
            >
              <span class="align-text-top text-capitalize">
                {{ index + 1 }}. 滿 {{ condition.value }}
                {{ condition.type == 1 ? "元" : "件" }}
              </span>
            </div>
          </div>
        </template>

        <!-- Column: start_at -->
        <template #cell(start_at)="data">
          <div class="text-nowrap">
            <span class="align-text-top text-capitalize">{{
              data.item.start_at
            }}</span>
          </div>
        </template>

        <!-- Column: Actions -->
        <template #cell(actions)="data">
          <b-badge
            variant="light-secondary"
            class="cursor-pointer"
            :to="{
              name: 'promotions-discounts-edit',
              params: { id: data.item.id },
            }"
          >
            <feather-icon icon="EditIcon" class="mr-25" />
            <span>修改</span>
          </b-badge>
          <b-badge
            variant="light-danger"
            class="cursor-pointer"
            @click="deletePromotions(data.item.id, data.item.name)"
          >
            <feather-icon icon="TrashIcon" class="mr-25" />
            <span>刪除</span>
          </b-badge>
        </template>
      </b-table>
      <div class="mx-2 mb-2">
        <b-row>
          <b-col
            cols="12"
            sm="6"
            class="d-flex align-items-center justify-content-center justify-content-sm-start"
          >
            <span class="text-muted"
              >Showing {{ dataMeta.from }} to {{ dataMeta.to }} of
              {{ dataMeta.of }} entries</span
            >
          </b-col>
          <!-- Pagination -->
          <b-col
            cols="12"
            sm="6"
            class="d-flex align-items-center justify-content-center justify-content-sm-end"
          >
            <b-pagination
              v-model="currentPage"
              :total-rows="totalNumber"
              :per-page="perPage"
              first-number
              last-number
              class="mb-0 mt-1 mt-sm-0"
              prev-class="prev-item"
              next-class="next-item"
            >
              <template #prev-text>
                <feather-icon icon="ChevronLeftIcon" size="18" />
              </template>
              <template #next-text>
                <feather-icon icon="ChevronRightIcon" size="18" />
              </template>
            </b-pagination>
          </b-col>
        </b-row>
      </div>
    </b-card>
  </div>
</template>

<script>
import {
  BCard,
  BRow,
  BCol,
  BFormInput,
  BButton,
  BTable,
  BMedia,
  BAvatar,
  BLink,
  BBadge,
  BDropdown,
  BDropdownItem,
  BPagination,
} from "bootstrap-vue";
import vSelect from "vue-select";
import store from "@/store";
import { ref, onUnmounted } from "@vue/composition-api";
import { avatarText } from "@core/utils/filter";
import useDiscountList from "./useDiscountList";
import promotionModule from "../promotionModule";
// import ProductClassMainAddNew from './ProductClassMainAddNew.vue'

export default {
  components: {
    // ProductClassMainAddNew,

    BCard,
    BRow,
    BCol,
    BFormInput,
    BButton,
    BTable,
    BMedia,
    BAvatar,
    BLink,
    BBadge,
    BDropdown,
    BDropdownItem,
    BPagination,

    vSelect,
  },
  setup() {
    const USER_APP_STORE_MODULE_NAME = "information";

    // Register module
    if (!store.hasModule(USER_APP_STORE_MODULE_NAME))
      store.registerModule(USER_APP_STORE_MODULE_NAME, promotionModule);

    // UnRegister on leave
    onUnmounted(() => {
      if (store.hasModule(USER_APP_STORE_MODULE_NAME))
        store.unregisterModule(USER_APP_STORE_MODULE_NAME);
    });

    const {
      fetchPromotions,
      deletePromotions,
      tableColumns,
      perPage,
      currentPage,
      totalNumber,
      dataMeta,
      perPageOptions,
      // searchQuery,
      sortBy,
      isSortDirDesc,
      promotionTable,
      refetchData,
    } = useDiscountList();

    return {
      fetchPromotions,
      deletePromotions,
      tableColumns,
      perPage,
      currentPage,
      totalNumber,
      dataMeta,
      perPageOptions,
      // searchQuery,
      sortBy,
      isSortDirDesc,
      promotionTable,
      refetchData,

      // Filter
      avatarText,
    };
  },
};
</script>

<style lang="scss" scoped>
.per-page-selector {
  width: 90px;
}
</style>

<style lang="scss">
@import "~@resources/scss/vue/libs/vue-select.scss";
</style>
